==> haskell-snap-core-1.0.3.2-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-snap-core.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: snap-core
version: 1.0.3.2
id: snap-core-1.0.3.2-95N1LvYemcgAk99Q6D5RzX
key: snap-core-1.0.3.2-95N1LvYemcgAk99Q6D5RzX
license: BSD-3-Clause
maintainer: snap@snapframework.com
author: Snap Framework Authors (see CONTRIBUTORS)
homepage: http://snapframework.com/
synopsis: Snap: A Haskell Web Framework (core interfaces and types)
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.
    .
    This library contains the core definitions and types for the Snap framework,
    including:
    .
    1. Primitive types and functions for HTTP (requests, responses, cookies,
    post/query parameters, etc)
    .
    2. A monad for programming web handlers called \"Snap\", which allows:
    .
    * Stateful access to the HTTP request and response objects
    .
    * Monadic failure (i.e. MonadPlus/Alternative instances) for declining
    to handle requests and chaining handlers together
    .
    * Early termination of the computation if you know early what you want
    to return and want to prevent further monadic processing
    .
    /Quick start/: The '\''Snap'\'' monad and HTTP definitions are in "Snap.Core".
category: Web, Snap, IO-Streams
abi: 053a7444c90bd7b8aefef71e88ae34ad
exposed: True
exposed-modules:
    Snap.Core Snap.Internal.Core Snap.Internal.Debug
    Snap.Internal.Http.Types Snap.Internal.Parsing Snap.Test
    Snap.Types.Headers Snap.Util.CORS Snap.Util.FileServe
    Snap.Util.FileUploads Snap.Util.GZip Snap.Util.Proxy
hidden-modules: Snap.Internal.Instances Snap.Internal.Routing
                Snap.Internal.Test.RequestBuilder Snap.Internal.Test.Assertions
                Snap.Internal.Util.FileServe Snap.Internal.Util.FileUploads
import-dirs: /usr/lib/ghc-8.4.3/site-local/snap-core-1.0.3.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/snap-core-1.0.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/snap-core-1.0.3.2
hs-libraries: HSsnap-core-1.0.3.2-95N1LvYemcgAk99Q6D5RzX
depends:
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
    attoparsec-0.13.2.2-3UshHsIb0S9BZJuxZmJPoQ base-4.11.1.0
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    containers-0.5.11.0 directory-1.3.1.5 filepath-1.4.2
    lifted-base-0.2.3.12-EZ86Th71kuIKONQzo515KS
    io-streams-1.5.0.1-3wxrXTlZ2wuID245XhZDFM
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    monad-control-1.0.2.3-DxusezgvvO4D8Mw0qz5Ueq mtl-2.2.2
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV
    readable-0.3.1-BcSBcf5TfYB2LKDbOZtqGx
    regex-posix-0.95.2-FLMmMz75XIwP5t3X8eXe text-1.2.3.0 time-1.8.0.2
    transformers-0.5.5.0
    transformers-base-0.4.5.2-HkOEnilApg71eKub9grpon
    unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y
    unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    network-2.6.3.5-Fx5sr8R0T187bG98MhcJGV
abi-depends: HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=6ff9610fd5e59ec310c47074d0590847
             attoparsec-0.13.2.2-3UshHsIb0S9BZJuxZmJPoQ=b6c55238d5ca948928baa2c3b9c37177
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             lifted-base-0.2.3.12-EZ86Th71kuIKONQzo515KS=b7feb9ada79ca4aa0bc32a0336d653d1
             io-streams-1.5.0.1-3wxrXTlZ2wuID245XhZDFM=f5c44f852f2e931198345b8254655a93
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             monad-control-1.0.2.3-DxusezgvvO4D8Mw0qz5Ueq=87bdbc4e9457b26289613d38f0adffd2
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             readable-0.3.1-BcSBcf5TfYB2LKDbOZtqGx=a4ad4e523dcb910f6ec9f00a480a8c50
             regex-posix-0.95.2-FLMmMz75XIwP5t3X8eXe=f82f008e033b543a72d9ae8bb46e8b27
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-base-0.4.5.2-HkOEnilApg71eKub9grpon=3700d08e9c0fb7ac1d166d53bb66cbcb
             unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y=31a73ccc78f384281114d092d52191fc
             unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu=5b052eced98346d45f3db03378f2841d
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=576647ddb2b9fe32850edc158395e14c
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=4ea8f0efa7a1ade0af4e9ce0cffcff8c
             network-2.6.3.5-Fx5sr8R0T187bG98MhcJGV=2d4c3651bc0be664be6ba47387ac45a3
haddock-interfaces: /usr/share/doc/haskell-snap-core/html/snap-core.haddock
haddock-html: /usr/share/doc/haskell-snap-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-snap-core-1.0.3.2-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-snap-core.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: snap-core
version: 1.0.3.2
id: snap-core-1.0.3.2-28QKtKnyDW5HIkbjeaeQ4j
key: snap-core-1.0.3.2-28QKtKnyDW5HIkbjeaeQ4j
license: BSD-3-Clause
maintainer: snap@snapframework.com
author: Snap Framework Authors (see CONTRIBUTORS)
homepage: http://snapframework.com/
synopsis: Snap: A Haskell Web Framework (core interfaces and types)
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.
    .
    This library contains the core definitions and types for the Snap framework,
    including:
    .
    1. Primitive types and functions for HTTP (requests, responses, cookies,
    post/query parameters, etc)
    .
    2. A monad for programming web handlers called \"Snap\", which allows:
    .
    * Stateful access to the HTTP request and response objects
    .
    * Monadic failure (i.e. MonadPlus/Alternative instances) for declining
    to handle requests and chaining handlers together
    .
    * Early termination of the computation if you know early what you want
    to return and want to prevent further monadic processing
    .
    /Quick start/: The '\''Snap'\'' monad and HTTP definitions are in "Snap.Core".
category: Web, Snap, IO-Streams
abi: 19fb02f35b4a40987fa65d7e94786f4f
exposed: True
exposed-modules:
    Snap.Core Snap.Internal.Core Snap.Internal.Debug
    Snap.Internal.Http.Types Snap.Internal.Parsing Snap.Test
    Snap.Types.Headers Snap.Util.CORS Snap.Util.FileServe
    Snap.Util.FileUploads Snap.Util.GZip Snap.Util.Proxy
hidden-modules: Snap.Internal.Instances Snap.Internal.Routing
                Snap.Internal.Test.RequestBuilder Snap.Internal.Test.Assertions
                Snap.Internal.Util.FileServe Snap.Internal.Util.FileUploads
import-dirs: /usr/lib/ghc-8.4.3/site-local/snap-core-1.0.3.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/snap-core-1.0.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/snap-core-1.0.3.2
hs-libraries: HSsnap-core-1.0.3.2-28QKtKnyDW5HIkbjeaeQ4j
depends:
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
    attoparsec-0.13.2.2-3UshHsIb0S9BZJuxZmJPoQ base-4.11.1.0
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    containers-0.5.11.0 directory-1.3.1.5 filepath-1.4.2
    lifted-base-0.2.3.12-EZ86Th71kuIKONQzo515KS
    io-streams-1.5.0.1-GVnvt4HWgciILzINo2uloz
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    monad-control-1.0.2.3-DxusezgvvO4D8Mw0qz5Ueq mtl-2.2.2
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV
    readable-0.3.1-BcSBcf5TfYB2LKDbOZtqGx
    regex-posix-0.95.2-FLMmMz75XIwP5t3X8eXe text-1.2.3.0 time-1.8.0.2
    transformers-0.5.5.0
    transformers-base-0.4.5.2-HkOEnilApg71eKub9grpon
    unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y
    unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    network-2.7.0.0-AFQUqm7hPUl7GJe3nXsQng
abi-depends: HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=6ff9610fd5e59ec310c47074d0590847
             attoparsec-0.13.2.2-3UshHsIb0S9BZJuxZmJPoQ=b6c55238d5ca948928baa2c3b9c37177
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             lifted-base-0.2.3.12-EZ86Th71kuIKONQzo515KS=b7feb9ada79ca4aa0bc32a0336d653d1
             io-streams-1.5.0.1-GVnvt4HWgciILzINo2uloz=bd8c76fdd1c3f4137d0e4a1236bde881
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             monad-control-1.0.2.3-DxusezgvvO4D8Mw0qz5Ueq=87bdbc4e9457b26289613d38f0adffd2
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             readable-0.3.1-BcSBcf5TfYB2LKDbOZtqGx=a4ad4e523dcb910f6ec9f00a480a8c50
             regex-posix-0.95.2-FLMmMz75XIwP5t3X8eXe=f82f008e033b543a72d9ae8bb46e8b27
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-base-0.4.5.2-HkOEnilApg71eKub9grpon=3700d08e9c0fb7ac1d166d53bb66cbcb
             unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y=31a73ccc78f384281114d092d52191fc
             unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu=5b052eced98346d45f3db03378f2841d
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=576647ddb2b9fe32850edc158395e14c
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=4ea8f0efa7a1ade0af4e9ce0cffcff8c
             network-2.7.0.0-AFQUqm7hPUl7GJe3nXsQng=f721cf34b8f5e16aaba2f249d1eefa28
haddock-interfaces: /usr/share/doc/haskell-snap-core/html/snap-core.haddock
haddock-html: /usr/share/doc/haskell-snap-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
